# 🌀 blue-south

AI for Global South: Free from Big Tech.

```bash
pip install blue-south
```

|   |   |   |
| --- | --- | --- |
| [`abcli`](https://github.com/kamangir/awesome-bash-cli) [![image](https://github.com/kamangir/assets/blob/main/awesome-bash-cli/marquee-2024-10-26.jpg?raw=true)](https://github.com/kamangir/awesome-bash-cli) A language to speak AI.  [![PyPI version](https://img.shields.io/pypi/v/abcli.svg)](https://pypi.org/project/abcli/) | [`blue_options`](https://github.com/kamangir/blue-options) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/blue-options) options for Bash.  [![PyPI version](https://img.shields.io/pypi/v/blue_options.svg)](https://pypi.org/project/blue_options/) | [`blue_objects`](https://github.com/kamangir/blue-objects) [![image](https://github.com/kamangir/assets/raw/main/blue-objects/marquee.png?raw=true)](https://github.com/kamangir/blue-objects) data objects for Bash.  [![PyPI version](https://img.shields.io/pypi/v/blue_objects.svg)](https://pypi.org/project/blue_objects/) |
| [`gizai`](https://github.com/kamangir/giza) [![image](https://github.com/kamangir/giza/raw/main/assets/giza.png)](https://github.com/kamangir/giza) Access, Automation, Analytics, AI - A Mathematical model for AI languages.  [![PyPI version](https://img.shields.io/pypi/v/gizai.svg)](https://pypi.org/project/gizai/) |  |  |

---


[![pylint](https://github.com/kamangir/blue-south/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-south/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-south/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-south/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-south/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-south/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-south.svg)](https://pypi.org/project/blue-south/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-south)](https://pypistats.org/packages/blue-south)

built by 🌀 [`blue_options-4.240.1`](https://github.com/kamangir/awesome-bash-cli), based on 🌀 [`blue_south-4.9.1`](https://github.com/kamangir/blue-south).
